from .QtCore import *
from .QtDBus import *
from .QtGui import *  # type: ignore[misc] # Incompatible import of "Qt" (imported name has type "Type[Qt.QtGui.Qt]", local name has type "Type[Qt.QtCore.Qt]")
from .QtNetwork import *
from .QtQml import *
from .QtWidgets import *
from .QtXml import *
from .QtOpenGL import *
from .QtPrintSupport import *
from .QtQuick import *
from .QtSql import *
from .QtSvg import *
from .QtTest import *
from .QtX11Extras import *
from .QtQuickWidgets import *

__binding__: str



import typing
 
from . import QtWidgets
 
 
class QHeaderView:
    @typing.overload
    @staticmethod
    def setSectionResizeMode(header: QtWidgets.QHeaderView, logicalIndex: int, mode: QtWidgets.QHeaderView.ResizeMode) -> None: ...
    @typing.overload
    @staticmethod
    def setSectionResizeMode(header: QtWidgets.QHeaderView, mode: QtWidgets.QHeaderView.ResizeMode) -> None: ...

def translate(context: str, sourceText: str, *args: typing.Any) -> str: ...
